[][src]Trait memory_units::ByteSize

pub trait ByteSize {
    const BYTE_SIZE: Bytes;
}

A trait defining the size, in bytes, of one unit of Self.

Example

println!("The size of one word in bytes is {}.", Words::BYTE_SIZE.0);

Associated Constants

The size, in bytes, of a single unit of Self.

Implementors

impl ByteSize for Bytes
[src]

impl ByteSize for memory_units::target::Pages
[src]

impl ByteSize for memory_units::target::Words
[src]

impl ByteSize for memory_units::wasm32::Pages
[src]

impl ByteSize for memory_units::wasm32::Words
[src]