[][src]Struct pwasm_abi::eth::Sink

pub struct Sink { /* fields omitted */ }

Sink for returning number of arguments

Methods

impl Sink
[src]

New sink with known capacity

Consume val to the Sink

Drain current Sink to the target vector

Consume current Sink to produce a vector with content. May panic if declared number of arguments does not match the resulting number of bytes should be produced.

Mutable reference to the Sink preamble

Mutable reference to the Sink heap