Trait AsLog
pwasm_abi::eth
pub trait AsLog { fn as_log(&self) -> H256; }
As log trait for how primitive types are represented as indexed arguments of the event log
fn as_log(&self) -> H256
Convert type to hash representation for the event log.
impl AsLog for H256
impl AsLog for U256
impl AsLog for Address
impl AsLog for bool
impl AsLog for i32
impl AsLog for i64
impl AsLog for u32
impl AsLog for u64