[−][src]Function pwasm_ethereum::balance
pub fn balance(address: &Address) -> U256
Get balance of the given account
If an account is not registered in the chain yet, it is considered as an account with balance=0
pub fn balance(address: &Address) -> U256
Get balance of the given account
If an account is not registered in the chain yet, it is considered as an account with balance=0