[−][src]Function pwasm_ethereum::origin
pub fn origin() -> Address
Get execution origination address
This is the sender of original transaction. It could be only external account, not a contract
pub fn origin() -> Address
Get execution origination address
This is the sender of original transaction. It could be only external account, not a contract