[−][src]Struct pwasm_std::hash::H264
Unformatted binary data of fixed length.
Methods
impl H264[src]
impl H264pub fn new() -> H264[src]
pub fn new() -> H264Create a new, zero-initialised, instance.
pub fn zero() -> H264[src]
pub fn zero() -> H264Synonym for new(). Prefer to new as it's more readable.
pub fn len() -> usize[src]
pub fn len() -> usizeGet the size of this object in bytes.
pub fn as_ptr(&self) -> *const u8[src]
pub fn as_ptr(&self) -> *const u8Returns a constant raw pointer to the value
pub fn as_mut_ptr(&mut self) -> *mut u8[src]
pub fn as_mut_ptr(&mut self) -> *mut u8Returns a mutable raw pointer to the value
pub fn clone_from_slice(&mut self, src: &[u8]) -> usize[src]
pub fn clone_from_slice(&mut self, src: &[u8]) -> usizeAssign self to be of the same value as a slice of bytes of length len().
pub fn from_slice(src: &[u8]) -> H264[src]
pub fn from_slice(src: &[u8]) -> H264Convert a slice of bytes of length len() to an instance of this type.
pub fn copy_to(&self, dest: &mut [u8])[src]
pub fn copy_to(&self, dest: &mut [u8])Copy the data of this object into some mutable slice of length len().
pub fn contains(&'a self, b: &'a H264) -> bool[src]
pub fn contains(&'a self, b: &'a H264) -> boolReturns true if all bits set in b are also set in self.
pub fn is_zero(&self) -> bool[src]
pub fn is_zero(&self) -> boolReturns true if no bits are set.
pub fn low_u64(&self) -> u64[src]
pub fn low_u64(&self) -> u64Returns the lowest 8 bytes interpreted as a BigEndian integer.