[][src]Struct pwasm_std::hash::H520

#[repr(C)]
pub struct H520(pub [u8; 65]);

Unformatted binary data of fixed length.

Methods

impl H520
[src]

Create a new, zero-initialised, instance.

Synonym for new(). Prefer to new as it's more readable.

Get the size of this object in bytes.

Returns a constant raw pointer to the value

Returns a mutable raw pointer to the value

Assign self to be of the same value as a slice of bytes of length len().

Convert a slice of bytes of length len() to an instance of this type.

Copy the data of this object into some mutable slice of length len().

Returns true if all bits set in b are also set in self.

Returns true if no bits are set.

Returns the lowest 8 bytes interpreted as a BigEndian integer.