[−][src]Struct wee_alloc::WeeAlloc
A wee allocator.
Safety
When used in unix environments, cannot move in memory. Typically not an
issue if you're just using this as a static global allocator.
Methods
impl<'a> WeeAlloc<'a>[src]
impl<'a> WeeAlloc<'a>pub const INIT: Self[src]
An initial const default construction of a WeeAlloc allocator.
This is usable for initializing statics that get set as the global
allocator.