[−][src]Struct pwasm_abi::eth::Sink
Sink for returning number of arguments
Methods
impl Sink[src]
impl Sinkpub fn new(capacity: usize) -> Self[src]
pub fn new(capacity: usize) -> SelfNew sink with known capacity
pub fn push<T: AbiType>(&mut self, val: T)[src]
pub fn push<T: AbiType>(&mut self, val: T)Consume val to the Sink
pub fn drain_to(self, target: &mut Vec<u8>)[src]
pub fn drain_to(self, target: &mut Vec<u8>)Drain current Sink to the target vector
pub fn finalize_panicking(self) -> Vec<u8>[src]
pub fn finalize_panicking(self) -> Vec<u8>Consume current Sink to produce a vector with content. May panic if declared number of arguments does not match the resulting number of bytes should be produced.
pub fn preamble_mut(&mut self) -> &mut Vec<u8>[src]
pub fn preamble_mut(&mut self) -> &mut Vec<u8>Mutable reference to the Sink preamble
pub fn heap_mut(&mut self) -> &mut Vec<u8>[src]
pub fn heap_mut(&mut self) -> &mut Vec<u8>Mutable reference to the Sink heap